@@ -8,7 +8,7 @@ use experimental qw[ postderef switch signatures ];
 
 use Exporter 'import';
 
-our $VERSION = '0.01'; # TRIAL
+our $VERSION = '0.02'; # TRIAL
 
 use Ref::Util qw[
   is_plain_arrayref is_arrayref
@@ -100,7 +100,10 @@ my %Validation = (
 );
 
 my %Validator
-  = map { $_ => validation_for( params => $Validation{$_}, name => $_ ) }
+  = map { $_ => validation_for( params => $Validation{$_},
+                                name => $_,
+                                name_is_optional => 1,
+                              ) }
   keys %Validation;
 
 sub _dup_context ( $context ) {
@@ -619,7 +622,7 @@ Data::Edit::Struct - Edit a Perl structure addressed with a Data::DPath path
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -661,9 +664,9 @@ The following actions may be performed on the destination structure:
 
 =over
 
-=item * C<pop> - remove one or more elements from the bottom of an array
+=item * C<shift> - remove one or more elements from the front of an array
 
-=item * C<shift> - remove one or more elements from the top of an array
+=item * C<pop> - remove one or more elements from the end of an array
 
 =item * C<splice> - invoke C<splice> on an array
 
@@ -787,7 +790,7 @@ container or an element.
 =item C<hash>
 
 The items are assembled into a hash.  The C<stype> parameter is used
-to determine whether that array is treated as a container or an
+to determine whether that hash is treated as a container or an
 element.  Keys are derived from the data:
 
 =over
@@ -882,7 +885,7 @@ the source structure is also changed:
  $src = { dogs => { say => "howl" } };
 
 To avoid this possible problem, C<Data::Edit::Struct> can be passed
-the L<< C<clone|/edit/clone> >> option, which will instruct it how to
+the L<< C<clone>|/clone >> option, which will instruct it how to
 copy data.
 
 =head1 SUBROUTINES
@@ -924,9 +927,9 @@ A reference to a structure or a L<Data::DPath::Context> object.
 
 =item C<spath>
 
-A string representing the data path. This may result in multiple
-extracted values from the structure; the action will be applied to
-each in turn.
+A string representing the source path. This may result in multiple
+extracted values from the structure; the C<sxfrm> option provides
+the context for how to interpret these values.
 
 =item C<stype>
 
@@ -934,6 +937,25 @@ May be C<auto>, C<element> or C<container>, to treat the extracted
 values either as elements or containers.  If C<auto>, non-blessed
 arrays and hashes are treated as containers.
 
+=item C<sxfrm>
+
+A transformation to be applied to the data extracted from the
+source. The available values are
+
+=over
+
+=item C<array>
+
+=item C<hash>
+
+=item C<iterate>
+
+=item I<coderef>
+
+=back
+
+See L</Source Transformations> for more information.
+
 =item C<clone>
 
 This may be a boolean or a code reference.  If a boolean, and true,
@@ -1116,9 +1138,9 @@ __END__
 #pod
 #pod =over
 #pod
-#pod =item  * C<pop> - remove one or more elements from the bottom of an array
+#pod =item  * C<shift> - remove one or more elements from the front of an array
 #pod
-#pod =item  * C<shift> - remove one or more elements from the top of an array
+#pod =item  * C<pop> - remove one or more elements from the end of an array
 #pod
 #pod =item  * C<splice> - invoke C<splice> on an array
 #pod
@@ -1221,7 +1243,7 @@ __END__
 #pod =item C<hash>
 #pod
 #pod The items are assembled into a hash.  The C<stype> parameter is used
-#pod to determine whether that array is treated as a container or an
+#pod to determine whether that hash is treated as a container or an
 #pod element.  Keys are derived from the data:
 #pod
 #pod =over
@@ -1313,7 +1335,7 @@ __END__
 #pod # COMMAND: perl ./examples/run copy1_0.pl copy1_1.pl  copy1_2.pl dump_src.pl
 #pod
 #pod To avoid this possible problem, C<Data::Edit::Struct> can be passed
-#pod the L<< C<clone|/edit/clone> >> option, which will instruct it how to
+#pod the L<< C<clone>|/clone >> option, which will instruct it how to
 #pod copy data.
 #pod
 #pod
@@ -1356,9 +1378,9 @@ __END__
 #pod
 #pod =item C<spath>
 #pod
-#pod A string representing the data path. This may result in multiple
-#pod extracted values from the structure; the action will be applied to
-#pod each in turn.
+#pod A string representing the source path. This may result in multiple
+#pod extracted values from the structure; the C<sxfrm> option provides
+#pod the context for how to interpret these values.
 #pod
 #pod =item C<stype>
 #pod
@@ -1366,6 +1388,24 @@ __END__
 #pod values either as elements or containers.  If C<auto>, non-blessed
 #pod arrays and hashes are treated as containers.
 #pod
+#pod =item C<sxfrm>
+#pod
+#pod A transformation to be applied to the data extracted from the
+#pod source. The available values are
+#pod
+#pod =over
+#pod
+#pod =item C<array>
+#pod
+#pod =item C<hash>
+#pod
+#pod =item C<iterate>
+#pod
+#pod =item I<coderef>
+#pod
+#pod =back
+#pod
+#pod See L</Source Transformations> for more information.
 #pod
 #pod =item C<clone>
 #pod
